@@ -7,6 +7,8 @@
 #include <Lum/Base/Size.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Def/MultiView.h>
+
 #include <Lum/Dlg/About.h>
 #include <Lum/Dlg/Msg.h>
 
@@ -24,7 +26,6 @@
 #include <Lum/Label.h>
 #include <Lum/Panel.h>
 #include <Lum/String.h>
-#include <Lum/Tab.h>
 #include <Lum/Text.h>
 #include <Lum/TextValue.h>
 #include <Lum/TimeSelect.h>
@@ -73,11 +74,11 @@ public:
 
   void PreInit()
   {
+    Lum::Def::MultiView   multiView(Lum::Def::Desc(L"DateJinni"));
     Lum::DateSelect       *dateSel;
     Lum::Label            *label;
     Lum::Panel            *panel;
     Lum::String           *string;
-    Lum::Tab              *tab;
     Lum::Text             *text;
     Lum::TextValue        *value;
     Lum::TimeSelect       *timeSel;
@@ -85,9 +86,7 @@ public:
     Lum::Base::SystemTime now;
     std::wstring          tmp;
 
-    tab=Lum::Tab::Create(true,true);
-
-    panel=Lum::VPanel::Create(true,false);
+    panel=Lum::VPanel::Create(true,true);
 
     label=Lum::Label::Create(true,false);
 
@@ -98,11 +97,11 @@ public:
     string->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typeDec));
     label->AddLabel(_(L"UNIX_TIME",L"Unix time:"),string);
 
-    value=Lum::TextValue::Create(utcResult,Lum::TextValue::right);
+    value=Lum::TextValue::Create(utcResult);
     value->SetMinWidth(Lum::Base::Size::stdCharWidth,now.GetUTCLocaleDateTime().length());
     label->AddLabel(_(L"UTC_TIME",L"UTC time:"),value);
 
-    value=Lum::TextValue::Create(localResult,Lum::TextValue::right);
+    value=Lum::TextValue::Create(localResult);
     value->SetMinWidth(Lum::Base::Size::stdCharWidth,now.GetLocalLocaleDateTime().length());
     label->AddLabel(_(L"LOCAL_TIME",L"Local time:"),value);
 
@@ -112,9 +111,10 @@ public:
     panel->Add(Lum::ButtonRow::Create(true,false)
                ->Add(Lum::Button::Create(_(L"CONVERT",L"_Convert"),convertUnix,true,false)));
 
-    tab->Add(_(L"FROM_UNIX",L"From Unix"),panel);
+    multiView.AddView(Lum::Def::MultiView::View(0,Lum::Def::Desc(_(L"FROM_UNIX",L"From Unix")),
+                                                panel));
 
-    panel=Lum::VPanel::Create(true,false);
+    panel=Lum::VPanel::Create(true,true);
 
     label=Lum::Label::Create(true,false);
 
@@ -135,7 +135,8 @@ public:
     panel->Add(Lum::ButtonRow::Create(true,false)
                ->Add(Lum::Button::Create(_(L"CONVERT",L"_Convert"),convertLocal,true,false)));
 
-    tab->Add(_(L"TO_UNIX",L"To Unix"),panel);
+    multiView.AddView(Lum::Def::MultiView::View(1,Lum::Def::Desc(_(L"TO_UNIX",L"To Unix")),
+                                                panel));
 
     tmp=_(L"DIFFERENCE",L"Difference between local time and UTC: ");
     tmp.append(Lum::Base::NumberToWString(now.GetDifferenceToUTC()));
@@ -156,24 +157,28 @@ public:
 
     text=new Lum::Text(tmp);
     text->SetFlex(true,true);
-    tab->Add(_(L"INFO",L"Info"),text);
 
-    SetMain(Lum::VPanel::Create(true,true)
-            ->Add(tab)
-            );
+    multiView.AddView(Lum::Def::MultiView::View(2,Lum::Def::Desc(_(L"INFO",L"Info")),
+                                                text));
 
-    Lum::Def::Menu *menu=Lum::Def::Menu::Create();
+    Lum::Def::Menu *preMenu=Lum::Def::Menu::Create();
 
-    menu
+    preMenu
       ->GroupProject()
         ->ActionQuit(GetClosedAction())
-      ->End()
+      ->End();
+
+    Lum::Def::Menu *postMenu=Lum::Def::Menu::Create();
+
+    postMenu
       ->GroupHelp()
         //->Action(Lum::Def::Action(Lum::Def::Desc(_ld(menuHelpHelp)),NULL))
         ->ActionAbout(about)
       ->End();
 
-    SetMenu(menu);
+    multiView.SetMenu(preMenu,postMenu);
+
+    Lum::OS::display->GetBehaviour()->ApplyMultiViewDlg(this,multiView);
 
     Dialog::PreInit();
   }
